module Data.String.Ubc.Parse.Language
( languageDef
)
where

import Text.Parsec
import Text.Parsec.Token
import Text.Parsec.Language

languageDef :: GenLanguageDef String u m
languageDef = LanguageDef {
          commentStart = "/*"
        , commentEnd = "*/"
        , commentLine = "//"
        , nestedComments = True
        , identStart = letter <|> char '_'
        , identLetter = alphaNum <|> char '_'
        , opStart = oneOf "+-*/"
        , opLetter = oneOf "+-*/"
        , reservedNames = [ "struct", "u32", "i32", "f32" ]
        }

tokenParser :: GenTokenParser String u m
tokenParser = makeTokenParser languageDef

TokenParser{
          identifier = identifier
        , reserved = reserved
        , operator = operator
        , reservedOp = reservedOperator
        , charLiteral = characterLiteral
        , stringLiteral = stringLiteral
        , natural = natural -- decimal, hexadecimal or octal
        , integer = integer -- decimal, hexadecimal or octal
        , float = float
        , naturalOrFloat = naturalOrFloat
        , decimal = decimal
        , hexadecimal = hexadecimal
        , octal = octal
        , symbol = symbol
        } = tokenParser
